@@ -1,6 +1,9 @@
 from __future__ import unicode_literals
-from django.utils.encoding import smart_text
-from django.utils.html import format_html
+try:
+    from django.utils.encoding import smart_text
+except ImportError:
+    from django.utils.encoding import smart_unicode as smart_text
+from .compat import format_html
 from django.core.urlresolvers import NoReverseMatch
 from django.core.urlresolvers import reverse
 
